import math

def square(side):
    return side * side

def rectangle(length, width):
    return length * width

def circle(radius):
    return math.pi * radius * radius

def triangle(base, height):
    return 0.5 * base * height



from setuptools import setup, find_packages

setup(
    name="area-codersao",      # must be unique on PyPI
    version="0.1",
    packages=find_packages(),
    description="A simple library to calculate area of shapes",
    author="Jatin Ghoyal",
    author_email="codersao@gmail.com",
)
